@@ -14,7 +14,7 @@ VKGallery::VKGallery(QWidget *parent) :
 
     this->sm = new ServiceMgr(this);
 
-    connect(sm, SIGNAL(errorOccured(QString, QTransport::Action)), this, SLOT(gotErrorMsg(QString, QTransport::Action)));
+    connect(sm, SIGNAL(errorOccured(QString, QTransport::Action, bool)), this, SLOT(gotErrorMsg(QString, QTransport::Action, bool)));
 
     panel = new ImageBrowserPanel(this->sm, this);
     panel->setFont(this->usedFont);
@@ -58,6 +58,8 @@ void VKGallery::createMenus()
     QMenu *mmenu = menuBar()->addMenu(tr("File"));
     QAction *action = mmenu->addAction(tr("Full screen"));
     connect(action, SIGNAL(triggered()), this, SLOT(actionFull_screen_toggled()));
+    action = mmenu->addAction(tr("Upload images"));
+    connect(action, SIGNAL(triggered()), this, SLOT(actionUploadPhoto_toggled()));
 #ifndef Q_WS_MAEMO_5
     action = mmenu->addAction(tr("Exit"));
     connect(action, SIGNAL(triggered()), this, SLOT(close()));
@@ -96,6 +98,11 @@ void VKGallery::changeEvent(QEvent *e)
     }
 }
 
+void VKGallery::closeEvent(QCloseEvent*)
+{
+    emit closeDialogs();
+}
+
 void VKGallery::help()
 {
     QString path;
@@ -128,6 +135,13 @@ void VKGallery::about()
     windowHelp->show();
 }
 
+void VKGallery::actionUploadPhoto_toggled()
+{
+    QPhotoUploader *uploader = new QPhotoUploader(this->sm, this);
+    //uploader->setModal(true);
+    uploader->show();
+}
+
 void VKGallery::actionFull_screen_toggled()
 {
     bool isFullScreen = windowState() & Qt::WindowFullScreen;
@@ -166,7 +180,11 @@ void VKGallery::actionAppSettings_toggled()
     settings->show();
 }
 
-void VKGallery::gotErrorMsg(QString errorMsg, QTransport::Action acc) {
+void VKGallery::gotErrorMsg(QString errorMsg, QTransport::Action acc, bool isMajor) {
+
+    if (!isMajor)
+        return;
+
 #ifdef Q_WS_MAEMO_5
 //hildon_banner_show_information(0, "", errorMsg.toUtf8().data());
     QDBusMessage msg = QDBusMessage::createMethodCall("org.freedesktop.Notifications", "/org/freedesktop/Notifications",
@@ -181,6 +199,7 @@ void VKGallery::gotErrorMsg(QString errorMsg, QTransport::Action acc) {
 
     QDBusConnection::systemBus().call(msg);
 #else
+#ifdef ENABLE_NOTIFY
     NotifyNotification *notification;
     /* Create notification */
     notification = notify_notification_new(APP_NAME,
@@ -196,8 +215,10 @@ void VKGallery::gotErrorMsg(QString errorMsg, QTransport::Action acc) {
         g_object_unref(notification);
     } else
         qDebug("Failed to create notification");
-//    QMessageBox::warning(this, tr("Error occured"),
-//                             errorMsg);
+#else
+    QMessageBox::warning(this, tr("Error occured"),
+                             errorMsg);
+#endif
 #endif
 
     if (acc == QTransport::getListFriendsAction)
